@@ -13,7 +13,7 @@
 ##############################################################################
 """Adding implementation tests
 
-$Id: test_adding.py 85553 2008-04-21 17:35:27Z lgs $
+$Id: test_adding.py 87370 2008-06-13 16:53:53Z ccomb $
 """
 import unittest
 
@@ -225,7 +225,7 @@ def test_constraint_driven_addingInfo():
     ...                      'TestMenu')
 
     >>> defineMenuItem(TestMenu, IAdding, '', 'item1')
-    >>> defineMenuItem(TestMenu, IAdding, '', 'item2')
+    >>> defineMenuItem(TestMenu, IAdding, '', 'Item2')
 
     >>> defineMenuItem(AddMenu, IAdding, '', 'item3', extra={'factory': 'f1'})
     >>> defineMenuItem(AddMenu, IAdding, '', 'item4', extra={'factory': 'f2'})
@@ -264,18 +264,18 @@ def test_constraint_driven_addingInfo():
     >>> len(items)
     1
     >>> items[0]['title']
-    'item3'
+    u'item3'
 
     >>> adding.menu_id = 'TestMenu'
     >>> items = adding.addingInfo()
     >>> len(items)
     3
     >>> items[0]['title']
-    'item1'
-    >>> items[1]['title']
-    'item2'
+    u'item1'
+    >>> items[1]['title'] # the collator ordered this one correctly!
+    u'Item2'
     >>> items[2]['title']
-    'item3'
+    u'item3'
     """
 
 def test_constraint_driven_add():
